@@ -8,7 +8,7 @@
 // Zlib decompressor
 #include <zlib.h>
 #include <boost/log/trivial.hpp>
-#include <bson.h>
+#include <bson/bson.h>
 #include <sstream>
 #include <map>
 #include "include/ChunkMetric.h"
