@@ -5,13 +5,10 @@
 #include "MergerTasksList.h"
 
 void
-MergerTasksList::push(std::string & metricName, int  index){
+MergerTasksList::push(std::string & metricName, int  index, std::vector<Chunk *> *chunkVector, size_t metricLength){
     mu.lock();
-
-    MergerTask *t = new MergerTask(metricName, index);
-
+    MergerTask *t = new MergerTask(metricName, index, chunkVector,  metricLength);
     mergerTasks.push(t);
-
     mu.unlock();
 }
 
