@@ -7,7 +7,7 @@
 
 #include <string>
 #include <vector>
-#include <bson.h>
+#include <bson/bson.h>
 
 class ChunkMetric {
 
