@@ -27,7 +27,7 @@ public:
     size_t getMetricNames(std::vector< std::string> & metricNames);
     [[nodiscard]] size_t getMetricLength() const { return samplesInDataset; }
 
-    MetricsPtr getMetric(std::string   metricName);
+    MetricsPtr getMetric(std::string   metricName, long start, long end);
 
     std::map<std::string, MetricsPtr> getHashMetrics() { return hashMapMetrics; }
     size_t getMetricNamesCount() { return metricNames.size(); }
