@@ -11,9 +11,9 @@
 
 class MergerTasksList {
 public:
-    MergerTasksList() {};
+    MergerTasksList() = default;;
 
-    void push(std::string & metricName, int index);
+    void push(std::string & metricName, int index, std::vector<Chunk *> *chunkVector, size_t metricLength);
     MergerTask *pop();
     bool empty();
 private:
