@@ -6,15 +6,16 @@
 #include <FTDCParser.h>
 #include <vector>
 #include <filesystem>
-#include <boost/log/core.hpp>
-#include <boost/log/trivial.hpp>
-#include <boost/log/expressions.hpp>
+
 
 namespace py = pybind11;
 
 typedef std::vector<uint64_t>* Metrics;
 typedef std::vector<std::string> MetricNames;
 
+
+#define FALSE 0
+
 #define STRINGIFY(x) #x
 #define MACRO_STRINGIFY(x) STRINGIFY(x)
 
@@ -68,7 +69,7 @@ struct ParserClass {
             // Timestamps, metric names, and metadata as fields in python
             metric_names = pParser->getMetricsNames();
             metadata = pParser->getMetadata();
-            timestamps = pParser->getMetric( "start");
+            timestamps = pParser->getMetric("start", 0, 0);
             sample_count = pParser->getMetricLength();
         }
         return n;
@@ -89,7 +90,7 @@ struct ParserClass {
                 // metric names and metadata as fields in python
                 metric_names = pParser->getMetricsNames();
                 metadata = pParser->getMetadata();
-                timestamps = pParser->getMetric( "start");
+                timestamps = pParser->getMetric("start", 0, 0);
 
                 sample_count = pParser->getMetricLength();
             }
@@ -99,38 +100,37 @@ struct ParserClass {
         return -1;
     }
     Metrics  get_timestamps() {
-        return pParser->getMetric((std::string &) "start");
+        return pParser->getMetric((std::string &) "start", 0, 0);
     }
-    Metrics  getMetric(std::string metricName) {
-        return pParser->getMetric(metricName);
+    Metrics  getMetric(std::string metricName, long start = -1, long end = -1) {
+        return pParser->getMetric(metricName, start, end);
     }
     uint64_t getMetricSampleCount() {
         return pParser->getMetricLength();
     }
-    py::array_t<unsigned long>  getMetricAsNumpyArray(std::string metricName) {
-        auto m = pParser->getMetric(metricName);
+    py::array_t<unsigned long>  getMetricAsNumpyArray(std::string metricName, long start = -1, long end = -1) {
+        auto m = pParser->getMetric(metricName, start, end);
         return as_pyarray(m);
     }
-    std::vector<py::array_t<unsigned long>> getMetricListAsNumpyArray(std::vector<std::string> metricNames) {
+    std::vector<py::array_t<unsigned long>> getMetricListAsNumpyArray(std::vector<std::string> metricNames, long start = -1, long end = -1) {
         std::vector<py::array_t<unsigned long>> metricList;
 
         for(auto name : metricNames) {
-            auto element = as_pyarray( pParser->getMetric(name));
+            auto element = as_pyarray(pParser->getMetric(name, 0, 0));
             metricList.emplace_back(element);
         }
         return metricList;
     }
-
-    py::array_t<uint64_t>  getMetricListAsNumpyMatrix(std::vector<std::string> metricNames, bool transposed=Py_False) {
+    py::array_t<uint64_t>  getMetricListAsNumpyMatrix(std::vector<std::string> metricNames, bool transposed= FALSE) {
 
         if (transposed) {
             py::array_t<uint64_t, py::array::f_style> a;
             a.resize({(int) metricNames.size(), (int) pParser->getMetricLength()});
             auto r = a.mutable_unchecked();
             for (py::ssize_t i = 0; i < r.shape(0); i++) {
-                auto element = pParser->getMetric(metricNames[i]);
+                auto element = pParser->getMetric(metricNames[i], 0, 0);
                 for (py::ssize_t j = 0; j < r.shape(1); j++)
-                    r(i, j) = element->at(j);
+                    r(j, i) = element->at(j);
             }
             return a;
         }
@@ -140,32 +140,15 @@ struct ParserClass {
             a.resize({(int) metricNames.size(), (int) pParser->getMetricLength()});
             auto r = a.mutable_unchecked();
             for (py::ssize_t i = 0; i < r.shape(0); i++) {
-                auto element = pParser->getMetric(metricNames[i]);
+                auto element = pParser->getMetric(metricNames[i], 0, 0);
                 for (py::ssize_t j = 0; j < r.shape(1); j++)
                     r(i, j) = element->at(j);
             }
             return a;
         }
-
     }
 
-    py::array_t<uint64_t> miau(std::vector<std::string> metricNames) {
-        py::array_t<uint64_t , py::array::c_style> a;
-        a.resize({(int)metricNames.size(), (int)pParser->getMetricLength()});
 
-        auto  dims = a.ndim();
-        printf("Dimensions %ld\n", dims);
-
-        auto r = a.mutable_unchecked();
-        printf("Shapes %ld, %ld\n", r.shape(0), r.shape(1));
-        for (py::ssize_t i=0; i<r.shape(0); i++) {
-            auto element = pParser->getMetric(metricNames[i]);
-            for (py::ssize_t j=0; j<r.shape(1); j++) {
-                r(i,j) = element->at(j);
-            }
-        }
-        return a;
-    }
 };
 
 
@@ -211,7 +194,9 @@ PYBIND11_MODULE(_core, m) {
         .def_readonly("sample_count", &ParserClass::sample_count)
         .def("get_metric_numpy", &ParserClass::getMetricAsNumpyArray)
         .def("get_metrics_list_numpy", &ParserClass::getMetricListAsNumpyArray)
-        .def("get_metrics_list_numpy_matrix", &ParserClass::getMetricListAsNumpyMatrix)
+        .def("get_metrics_list_numpy_matrix", &ParserClass::getMetricListAsNumpyMatrix,
+             "Returns a matrix of metrics",
+             py::arg("metricNames"), py::arg("transposed") = FALSE)
         ;
 
 
