@@ -20,12 +20,9 @@
 
 #include <filesystem>
 
-static const char *DATA_TEST_FILE_NAME = "../../../tests_cpp_tests/metrics.data";
-static const char *CSV__TEST_FILE_NAME = "../../../tests_cpp_tests/first.csv";
-
-
-static const char *DATA_TEST_FILE_NAME2 = "../../../tests/diagnostic.data_40/metrics.2021-07-17T22-36-31Z-00000";
-static const char *DATA_TEST_DIR = "../../../tests/diagnostic.data_40/";
+static const char *DATA_TEST_FILE_NAME = "/Users/jorge.imperial/CLionProjects/mongo_ftdc/tests/cpp_tests/metrics.data";
+static const char *CSV__TEST_FILE_NAME = "/Users/jorge.imperial/CLionProjects/mongo_ftdc/tests/cpp_tests/first.csv";
+static const char *DATA_TEST_DIR = "/Users/jorge.imperial/CLionProjects/mongo_ftdc/tests/diagnostic.data_40/";
 
 
 int ParserTaskConsumerThread(ParserTasksList *parserTasks, Dataset *dataSet);
@@ -423,7 +420,7 @@ BOOST_AUTO_TEST_SUITE(ftdc_basic_suite)
         BOOST_CHECK_EQUAL(status, 0);
 
         auto ts = parser->getMetric("start");
-        auto end = parser->getMetric( "end");
+        auto end = parser->getMetric("end");
         uint64_t prevTimestamp = (*ts)[0] / 1000;
         uint64_t thisTimestamp, endTimeStamp;
         for (int i = 1; i < ts->size(); ++i) {
@@ -484,11 +481,11 @@ BOOST_AUTO_TEST_SUITE(ftdc_basic_suite)
         auto msg = str(boost::format("Metric count is %1%") % metricNames.size());
         BOOST_TEST_MESSAGE(msg);
 
-        auto ts = parser->getMetric("start");
-        auto m1 = parser->getMetric(metricNames[1]);
-        auto m2 = parser->getMetric(metricNames[3]);
-        auto m3 = parser->getMetric(metricNames[5]);
-        auto m4 = parser->getMetric(metricNames[7]);
+        auto ts = parser->getMetric("start", 0, 0);
+        auto m1 = parser->getMetric(metricNames[1], 0, 0);
+        auto m2 = parser->getMetric(metricNames[3], 0, 0);
+        auto m3 = parser->getMetric(metricNames[5], 0, 0);
+        auto m4 = parser->getMetric(metricNames[7], 0, 0);
 
         msg = str( boost::format("Timestamp has %1% elements\n%2%:%3%\n%4%:%5%\n%6%:%7%\n%8%:%9%\n") % ts->size() %
                 metricNames[1] % m1->size() %
